package App::PrettyRes;

our $VERSION = '0.02'; # VERSION
our $DATE = '2015-01-03'; # DATE

1;
# ABSTRACT: Format enveloped result prettily

__END__

=pod

=encoding UTF-8

=head1 NAME

App::PrettyRes - Format enveloped result prettily

=head1 VERSION

This document describes version 0.02 of App::PrettyRes (from Perl distribution App-PrettyRes), released on 2015-01-03.

=head1 SYNOPSIS

See the provided command-line script L<pretty-res>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PrettyRes>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-PrettyRes>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PrettyRes>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
